==> ideaIC-2018.3.3-sources.jar: com/intellij/codeInsight/template/macro/ConcatMacro.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInsight.template.macro;

import com.intellij.codeInsight.template.Expression;
import com.intellij.codeInsight.template.ExpressionContext;
import com.intellij.codeInsight.template.Result;
import com.intellij.codeInsight.template.TextResult;
import com.intellij.openapi.util.text.StringUtil;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class ConcatMacro extends MacroBase {
  public ConcatMacro() {
    super("concat", "concat(expressions...)");
  }

  @Nullable
  @Override
  protected Result calculateResult(@NotNull Expression[] params, ExpressionContext context, boolean quick) {
    StringBuilder result = new StringBuilder();
    for (Expression param : params) {
      Result paramResult = param.calculateResult(context);
      if (paramResult != null) {
        result.append(StringUtil.notNullize(paramResult.toString()));
      }
    }
    return result.length() != 0 ? new TextResult(result.toString()) : null;
  }
}

==> ideaIC-2021.1.1-sources.jar: com/intellij/codeInsight/template/macro/ConcatMacro.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.codeInsight.template.macro;

import com.intellij.codeInsight.template.Expression;
import com.intellij.codeInsight.template.ExpressionContext;
import com.intellij.codeInsight.template.Result;
import com.intellij.codeInsight.template.TextResult;
import com.intellij.openapi.util.text.StringUtil;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class ConcatMacro extends MacroBase {
  public ConcatMacro() {
    super("concat", "concat(expressions...)");
  }

  @Nullable
  @Override
  protected Result calculateResult(Expression @NotNull [] params, ExpressionContext context, boolean quick) {
    StringBuilder result = new StringBuilder();
    for (Expression param : params) {
      Result paramResult = param.calculateResult(context);
      if (paramResult != null) {
        result.append(StringUtil.notNullize(paramResult.toString()));
      }
    }
    return result.length() != 0 ? new TextResult(result.toString()) : null;
  }
}
